@@ -272,8 +272,13 @@ def resample_summary_to_daily(para_combination, folder=''):
 
     start_date = para_combination['start_date']
     end_date = para_combination['end_date']
-    sectype = para_combination['sectype']
-    lot_size = para_combination['lot_size']
+
+    sec_profile = para_combination['sec_profile']
+    sectype = sec_profile['sectype']
+    lot_size_dict = sec_profile['lot_size_dict']
+    code = para_combination['code']
+    lot_size = lot_size_dict[code]
+
     intraday = para_combination['intraday']
     freq = para_combination['freq']
     file_format = para_combination['file_format']
@@ -290,6 +295,7 @@ def resample_summary_to_daily(para_combination, folder=''):
 
     df_backtest['date'] = pd.to_datetime(df_backtest['date'], format='%Y-%m-%d')
     df_backtest = df_backtest.loc[(df_backtest['date'] >= start_date) & (df_backtest['date'] <= end_date)]
+    df_backtest = df_backtest.loc[df_backtest['action'].isnull() == False].copy() # All backtest force to treart as summary, ie filter action only
     df_backtest = df_backtest.reset_index(drop=True)  # Reset Index
 
     trade_pair = zip(*(iter(list(df_backtest.index)),) * 2)  # Group df_backtest by 2
@@ -299,8 +305,17 @@ def resample_summary_to_daily(para_combination, folder=''):
     # Read source data
     data_folder = para_combination['data_folder']
     code = para_combination['code']
-    data_path = os.path.join(folder,data_folder, f'{code}_{freq}.csv')
-    df_csv = pd.read_csv(data_path)
+
+
+    data_path = os.path.join(folder,data_folder, f'{code}_{freq}.{file_format}')
+    if file_format == 'parquet':
+        df_csv = pd.read_parquet(data_path)
+    else:
+        df_csv = pd.read_csv(data_path, index_col=0)
+
+    df_csv = df_csv.reset_index(drop=False)
+
+
     df_daily = pd.DataFrame()  # Dataframe for Daily
     df_daily['open'] = df_csv['open']
     df_daily['high'] = df_csv['high']
